@@ -1,4 +1,4 @@
-/* tftp-hpa: $Id: tftpd.c,v 1.33 2001/11/12 10:03:04 hpa Exp $ */
+/* tftp-hpa: $Id: tftpd.c,v 1.34 2001/11/13 03:11:52 hpa Exp $ */
 
 /* $OpenBSD: tftpd.c,v 1.13 1999/06/23 17:01:36 deraadt Exp $	*/
 
@@ -45,7 +45,7 @@ static const char *copyright UNUSED =
 /*static char sccsid[] = "from: @(#)tftpd.c	5.13 (Berkeley) 2/26/91";*/
 /*static char rcsid[] = "$OpenBSD: tftpd.c,v 1.13 1999/06/23 17:01:36 deraadt Exp $: tftpd.c,v 1.6 1997/02/16 23:49:21 deraadt Exp $";*/
 static const char *rcsid UNUSED =
-"tftp-hpa $Id: tftpd.c,v 1.33 2001/11/12 10:03:04 hpa Exp $";
+"tftp-hpa $Id: tftpd.c,v 1.34 2001/11/13 03:11:52 hpa Exp $";
 #endif /* not lint */
 
 /*
@@ -926,7 +926,7 @@ tftp_sendfile(struct formats *pf, struct tftphdr *oap, int oacklen)
 {
   struct tftphdr *dp;
   struct tftphdr *ap;		/* ack packet */
-  static int block = 1;		/* Static to avoid longjmp funnies */
+  static u_short block = 1;	/* Static to avoid longjmp funnies */
   int size, n;
   
   ap = (struct tftphdr *)ackbuf;
@@ -1036,8 +1036,9 @@ tftp_recvfile(struct formats *pf, struct tftphdr *oap, int oacklen)
   int n, size;
   /* These are "static" to avoid longjmp funnies */
   static struct tftphdr *ap;    /* ack buffer */
-  static int block = 0, acksize;
-  
+  static u_short block = 0;
+  static int acksize;
+
   dp = w_init();
   do {
     timeout = 0;
